diff src/protocols/oscar/msgcookie.c @ 13239:f260d319bbbc

[gaim-migrate @ 15605] Renaming a bunch of structs and typedefs to use the same naming scheme as the rest of Gaim committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Sun, 12 Feb 2006 16:02:05 +0000
parents f2431a7e33aa
children 6519aeb66b31
line wrap: on
line diff
--- a/src/protocols/oscar/msgcookie.c	Sun Feb 12 15:27:11 2006 +0000
+++ b/src/protocols/oscar/msgcookie.c	Sun Feb 12 16:02:05 2006 +0000
@@ -45,9 +45,9 @@
  * @return returns -1 on error, 0 on append, 1 on update.  the cookie you pass
  *         in may be free'd, so don't count on its value after calling this!
  */
-faim_internal int aim_cachecookie(aim_session_t *sess, aim_msgcookie_t *cookie)
+faim_internal int aim_cachecookie(OscarSession *sess, IcbmCookie *cookie)
 {
-	aim_msgcookie_t *newcook;
+	IcbmCookie *newcook;
 
 	if (!sess || !cookie)
 		return -EINVAL;
@@ -78,9 +78,9 @@
  * @param type cookie type to look for
  * @return if found, returns the struct; if none found (or on error), returns NULL:
  */
-faim_internal aim_msgcookie_t *aim_uncachecookie(aim_session_t *sess, guint8 *cookie, int type)
+faim_internal IcbmCookie *aim_uncachecookie(OscarSession *sess, guint8 *cookie, int type)
 {
-	aim_msgcookie_t *cur, **prev;
+	IcbmCookie *cur, **prev;
 
 	if (!cookie || !sess->msgcookies)
 		return NULL;
@@ -98,7 +98,7 @@
 }
 
 /**
  * aim_mkcookie - generate an aim_msgcookie_t *struct from a cookie string, a type, and a data pointer.
  *
  * @param c pointer to the cookie string array
  * @param type cookie type to use
@@ -106,14 +106,14 @@
  * @return returns NULL on error, a pointer to the newly-allocated
  *         cookie on success.
  */
-faim_internal aim_msgcookie_t *aim_mkcookie(guint8 *c, int type, void *data)
+faim_internal IcbmCookie *aim_mkcookie(guint8 *c, int type, void *data)
 {
-	aim_msgcookie_t *cookie;
+	IcbmCookie *cookie;
 
 	if (!c)
 		return NULL;
 
-	if (!(cookie = calloc(1, sizeof(aim_msgcookie_t))))
+	if (!(cookie = calloc(1, sizeof(IcbmCookie))))
 		return NULL;
 
 	cookie->data = data;
@@ -133,9 +133,9 @@
  *         on success; returns NULL on error/not found
  */
 
-faim_internal aim_msgcookie_t *aim_checkcookie(aim_session_t *sess, const guint8 *cookie, int type)
+faim_internal IcbmCookie *aim_checkcookie(OscarSession *sess, const guint8 *cookie, int type)
 {
-	aim_msgcookie_t *cur;
+	IcbmCookie *cur;
 
 	for (cur = sess->msgcookies; cur; cur = cur->next) {
 		if ((cur->type == type) &&
@@ -147,7 +147,7 @@
 }
 
 /**
  * aim_cookie_free - free an aim_msgcookie_t struct
  *
  * this function removes the cookie *cookie from the list of cookies
  * in sess, and then frees all memory associated with it. including
@@ -159,9 +159,9 @@
  * @return returns -1 on error, 0 on success.
  *
  */
-faim_internal int aim_cookie_free(aim_session_t *sess, aim_msgcookie_t *cookie)
+faim_internal int aim_cookie_free(OscarSession *sess, IcbmCookie *cookie)
 {
-	aim_msgcookie_t *cur, **prev;
+	IcbmCookie *cur, **prev;
 
 	if (!sess || !cookie)
 		return -EINVAL;
@@ -98,7 +98,7 @@
 
 /**
- * aim_mkcookie - generate an aim_msgcookie_t *struct from a cookie string, a type, and a data pointer.
+ * aim_mkcookie - generate an IcbmCookie *struct from a cookie string, a type, and a data pointer.
  *
  * @param c pointer to the cookie string array
@@ -147,7 +147,7 @@
 
 /**
- * aim_cookie_free - free an aim_msgcookie_t struct
+ * aim_cookie_free - free an IcbmCookie struct
  *
  * this function removes the cookie *cookie from the list of cookies